<?php

/**
 * Represents a Fusion server resource.
 */
class SearchApiFusionConnection extends SearchApiSolrConnection {

  /**
   * Route search requests to the Query API (api/apps/<app>/query/<query-profile>).
   * Route other requests to the Solr API (api/<app>/<handler>).
   *
   * @see https://doc.lucidworks.com/fusion-server/4.1/reference-guides/api/apps-api.html
   * @see https://doc.lucidworks.com/fusion-server/4.1/reference-guides/api/query-api.html
   * @see https://doc.lucidworks.com/fusion-server/4.1/reference-guides/api/solr-api.html
   */
  protected function constructUrl($servlet, array $params = array(), $added_query_string = NULL) {
    switch($servlet) {
      case self::SEARCH_SERVLET:
        $servlet = 'apps/' . $this->options['fusion_app'] . '/query/' . $this->options['fusion_qprofile_search'];
        break;
      default:
        $servlet = 'solr/' . $this->options['fusion_app'] . '/' . $servlet;
    }
    return parent::constructUrl($servlet, $params, $added_query_string);
  }

  /**
   * Get autocomplete suggestions.
   *
   * @param $searchQuery
   *   The search query.
   *
   * @see SearchApiAutocompleteSuggesterInterace::getAutocompleteSuggestions().
   */
  public function getAutocompleteSuggestions($searchQuery) {
    // Send request to Fusion.
    // search_api_page shows a maximum of 10 suggestions, so we request only 10 entries from Fusion.
    $servlet = 'apps/' . $this->options['fusion_app'] . '/query/' . $this->options['fusion_qprofile_autocomplete'];
    $params = array(
      'start' => 0,
      'rows' => 10,
      'q' => $searchQuery,
      'sort' => '',
    );

    $url = parent::constructurl($servlet, $params);
    $response = $this->sendRawGet($url);

    // Log response if necessary.
    if (!empty($this->options['log_query'])) {
      $this->logResponse($response);
    }

    // Parse response and return an array of suggestions.
    $suggestions = array();
    foreach ($response->response->docs as $doc) {
      $suggestions[] = $doc->query; // No need to sanitize (search_api_autocomplete takes care of this).
    }

    return $suggestions;
  }

}
