<?php
/**
 * @file
 * Contains the SearchApiSpellcheckFusion class.
 */

/**
 * Spellcheck class which can provide spelling suggestions. The constructor
 * populates the instance with any suggestions returned by Fusion.
 */
class SearchApiSpellcheckFusion extends SearchApiSpellcheck {

  /**
   * Constructs a SearchApiSpellcheckFusion object.
   *
   * If Fusion has returned spelling suggestion then loop through them and add
   * them to this spellcheck service, ordered by decreasing frequency.
   *
   * @see SearchApiSpellcheckSolr
   *
   * @param object $response
   *   The Fusion response object.
   */
  function __construct($response) {
    if (isset($response->spellcheck->suggestions)) {
      $suggestions = $response->spellcheck->suggestions;
      foreach ($suggestions as $word => $data) {
        if (isset($data->suggestion)) {
          usort($data->suggestion, array(self, 'compareFreq'));
          foreach ($data->suggestion as $suggestion) {
            $this->addSuggestion(new SearchApiSpellcheckSuggestion($word, $suggestion->word));
          }
        }
      }
    }
  }

  /**
   * Helper to order suggestions by frequency.
   */
  protected static function compareFreq($suggestion1, $suggestion2) {
    return $suggestion1->freq < $suggestion2->freq;
  }

}
